@@ -36,7 +36,7 @@ with DAG(
         'retries': 1,
         'retry_delay': timedelta(minutes=5),
     },
-    schedule_interval=None,
+    schedule_interval='@once',
     start_date=datetime(2018, 11, 1),
     tags=['example'],
 ) as dag:
