@@ -25,11 +25,13 @@ from urllib.parse import urlparse
 
 from airflow import models
 from airflow.exceptions import AirflowException
+from airflow.providers.apache.beam.operators.beam import (
+    BeamRunJavaPipelineOperator,
+    BeamRunPythonPipelineOperator,
+)
 from airflow.providers.google.cloud.hooks.dataflow import DataflowJobStatus
 from airflow.providers.google.cloud.operators.dataflow import (
     CheckJobRunning,
-    DataflowCreateJavaJobOperator,
-    DataflowCreatePythonJobOperator,
     DataflowTemplatedJobStartOperator,
 )
 from airflow.providers.google.cloud.sensors.dataflow import (
@@ -41,11 +43,11 @@ from airflow.providers.google.cloud.sensors.dataflow import (
 from airflow.providers.google.cloud.transfers.gcs_to_local import GCSToLocalFilesystemOperator
 from airflow.utils.dates import days_ago
 
-GCS_TMP = os.environ.get('GCP_DATAFLOW_GCS_TMP', 'gs://test-dataflow-example/temp/')
-GCS_STAGING = os.environ.get('GCP_DATAFLOW_GCS_STAGING', 'gs://test-dataflow-example/staging/')
-GCS_OUTPUT = os.environ.get('GCP_DATAFLOW_GCS_OUTPUT', 'gs://test-dataflow-example/output')
-GCS_JAR = os.environ.get('GCP_DATAFLOW_JAR', 'gs://test-dataflow-example/word-count-beam-bundled-0.1.jar')
-GCS_PYTHON = os.environ.get('GCP_DATAFLOW_PYTHON', 'gs://test-dataflow-example/wordcount_debugging.py')
+GCS_TMP = os.environ.get('GCP_DATAFLOW_GCS_TMP', 'gs://INVALID BUCKET NAME/temp/')
+GCS_STAGING = os.environ.get('GCP_DATAFLOW_GCS_STAGING', 'gs://INVALID BUCKET NAME/staging/')
+GCS_OUTPUT = os.environ.get('GCP_DATAFLOW_GCS_OUTPUT', 'gs://INVALID BUCKET NAME/output')
+GCS_JAR = os.environ.get('GCP_DATAFLOW_JAR', 'gs://INVALID BUCKET NAME/word-count-beam-bundled-0.1.jar')
+GCS_PYTHON = os.environ.get('GCP_DATAFLOW_PYTHON', 'gs://INVALID BUCKET NAME/wordcount_debugging.py')
 
 GCS_JAR_PARTS = urlparse(GCS_JAR)
 GCS_JAR_BUCKET_NAME = GCS_JAR_PARTS.netloc
@@ -60,23 +62,24 @@ default_args = {
 
 with models.DAG(
     "example_gcp_dataflow_native_java",
-    schedule_interval=None,  # Override to match your needs
+    schedule_interval='@once',  # Override to match your needs
     start_date=days_ago(1),
     tags=['example'],
 ) as dag_native_java:
 
     # [START howto_operator_start_java_job_jar_on_gcs]
-    start_java_job = DataflowCreateJavaJobOperator(
+    start_java_job = BeamRunJavaPipelineOperator(
         task_id="start-java-job",
         jar=GCS_JAR,
-        job_name='{{task.task_id}}',
-        options={
+        pipeline_options={
             'output': GCS_OUTPUT,
         },
-        poll_sleep=10,
         job_class='org.apache.beam.examples.WordCount',
-        check_if_running=CheckJobRunning.IgnoreJob,
-        location='europe-west3',
+        dataflow_config={
+            "check_if_running": CheckJobRunning.IgnoreJob,
+            "location": 'europe-west3',
+            "poll_sleep": 10,
+        },
     )
     # [END howto_operator_start_java_job_jar_on_gcs]
 
@@ -88,16 +91,18 @@ with models.DAG(
         filename="/tmp/dataflow-{{ ds_nodash }}.jar",
     )
 
-    start_java_job_local = DataflowCreateJavaJobOperator(
+    start_java_job_local = BeamRunJavaPipelineOperator(
         task_id="start-java-job-local",
         jar="/tmp/dataflow-{{ ds_nodash }}.jar",
-        job_name='{{task.task_id}}',
-        options={
+        pipeline_options={
             'output': GCS_OUTPUT,
         },
-        poll_sleep=10,
         job_class='org.apache.beam.examples.WordCount',
-        check_if_running=CheckJobRunning.WaitForRun,
+        dataflow_config={
+            "check_if_running": CheckJobRunning.WaitForRun,
+            "location": 'europe-west3',
+            "poll_sleep": 10,
+        },
     )
     jar_to_local >> start_java_job_local
     # [END howto_operator_start_java_job_local_jar]
@@ -106,32 +111,30 @@ with models.DAG(
     "example_gcp_dataflow_native_python",
     default_args=default_args,
     start_date=days_ago(1),
-    schedule_interval=None,  # Override to match your needs
+    schedule_interval='@once',  # Override to match your needs
     tags=['example'],
 ) as dag_native_python:
 
     # [START howto_operator_start_python_job]
-    start_python_job = DataflowCreatePythonJobOperator(
+    start_python_job = BeamRunPythonPipelineOperator(
         task_id="start-python-job",
         py_file=GCS_PYTHON,
         py_options=[],
-        job_name='{{task.task_id}}',
-        options={
+        pipeline_options={
             'output': GCS_OUTPUT,
         },
         py_requirements=['apache-beam[gcp]==2.21.0'],
         py_interpreter='python3',
         py_system_site_packages=False,
-        location='europe-west3',
+        dataflow_config={'location': 'europe-west3'},
     )
     # [END howto_operator_start_python_job]
 
-    start_python_job_local = DataflowCreatePythonJobOperator(
+    start_python_job_local = BeamRunPythonPipelineOperator(
         task_id="start-python-job-local",
         py_file='apache_beam.examples.wordcount',
         py_options=['-m'],
-        job_name='{{task.task_id}}',
-        options={
+        pipeline_options={
             'output': GCS_OUTPUT,
         },
         py_requirements=['apache-beam[gcp]==2.14.0'],
@@ -143,30 +146,33 @@ with models.DAG(
     "example_gcp_dataflow_native_python_async",
     default_args=default_args,
     start_date=days_ago(1),
-    schedule_interval=None,  # Override to match your needs
+    schedule_interval='@once',  # Override to match your needs
     tags=['example'],
 ) as dag_native_python_async:
     # [START howto_operator_start_python_job_async]
-    start_python_job_async = DataflowCreatePythonJobOperator(
+    start_python_job_async = BeamRunPythonPipelineOperator(
         task_id="start-python-job-async",
+        runner="DataflowRunner",
         py_file=GCS_PYTHON,
         py_options=[],
-        job_name='{{task.task_id}}',
-        options={
+        pipeline_options={
             'output': GCS_OUTPUT,
         },
         py_requirements=['apache-beam[gcp]==2.25.0'],
         py_interpreter='python3',
         py_system_site_packages=False,
-        location='europe-west3',
-        wait_until_finished=False,
+        dataflow_config={
+            "job_name": "start-python-job-async",
+            "location": 'europe-west3',
+            "wait_until_finished": False,
+        },
     )
     # [END howto_operator_start_python_job_async]
 
     # [START howto_sensor_wait_for_job_status]
     wait_for_python_job_async_done = DataflowJobStatusSensor(
         task_id="wait-for-python-job-async-done",
-        job_id="{{task_instance.xcom_pull('start-python-job-async')['job_id']}}",
+        job_id="{{task_instance.xcom_pull('start-python-job-async')['dataflow_job_id']}}",
         expected_statuses={DataflowJobStatus.JOB_STATE_DONE},
         location='europe-west3',
     )
@@ -190,9 +196,10 @@ with models.DAG(
 
     wait_for_python_job_async_metric = DataflowJobMetricsSensor(
         task_id="wait-for-python-job-async-metric",
-        job_id="{{task_instance.xcom_pull('start-python-job-async')['job_id']}}",
+        job_id="{{task_instance.xcom_pull('start-python-job-async')['dataflow_job_id']}}",
         location='europe-west3',
         callback=check_metric_scalar_gte(metric_name="Service-cpu_num_seconds", value=100),
+        fail_on_terminal_state=False,
     )
     # [END howto_sensor_wait_for_job_metric]
 
@@ -206,9 +213,10 @@ with models.DAG(
 
     wait_for_python_job_async_message = DataflowJobMessagesSensor(
         task_id="wait-for-python-job-async-message",
-        job_id="{{task_instance.xcom_pull('start-python-job-async')['job_id']}}",
+        job_id="{{task_instance.xcom_pull('start-python-job-async')['dataflow_job_id']}}",
         location='europe-west3',
         callback=check_message,
+        fail_on_terminal_state=False,
     )
     # [END howto_sensor_wait_for_job_message]
 
@@ -222,9 +230,10 @@ with models.DAG(
 
     wait_for_python_job_async_autoscaling_event = DataflowJobAutoScalingEventsSensor(
         task_id="wait-for-python-job-async-autoscaling-event",
-        job_id="{{task_instance.xcom_pull('start-python-job-async')['job_id']}}",
+        job_id="{{task_instance.xcom_pull('start-python-job-async')['dataflow_job_id']}}",
         location='europe-west3',
         callback=check_autoscaling_event,
+        fail_on_terminal_state=False,
     )
     # [END howto_sensor_wait_for_job_autoscaling_event]
 
@@ -238,7 +247,7 @@ with models.DAG(
     "example_gcp_dataflow_template",
     default_args=default_args,
     start_date=days_ago(1),
-    schedule_interval=None,  # Override to match your needs
+    schedule_interval='@once',  # Override to match your needs
     tags=['example'],
 ) as dag_template:
     # [START howto_operator_start_template_job]
