@@ -28,7 +28,7 @@ SPREADSHEET_ID = os.environ.get("SPREADSHEET_ID", "1234567890qwerty")
 with models.DAG(
     "example_sheets_to_gcs",
     start_date=days_ago(1),
-    schedule_interval=None,  # Override to match your needs
+    schedule_interval='@once',  # Override to match your needs
     tags=["example"],
 ) as dag:
     # [START upload_sheet_to_gcs]
