@@ -67,7 +67,7 @@ TASK = {
 
 with models.DAG(
     "example_gcp_tasks",
-    schedule_interval=None,  # Override to match your needs
+    schedule_interval='@once',  # Override to match your needs
     start_date=days_ago(1),
     tags=['example'],
 ) as dag:
