@@ -114,7 +114,7 @@ DETECT_IMAGE = {"source": {"image_uri": GCP_VISION_ANNOTATE_IMAGE_URL}}
 # [END howto_operator_vision_detect_image_param]
 
 with models.DAG(
-    'example_gcp_vision_autogenerated_id', start_date=days_ago(1), schedule_interval=None
+    'example_gcp_vision_autogenerated_id', schedule_interval='@once', start_date=days_ago(1)
 ) as dag_autogenerated_id:
     # ################################## #
     # ### Autogenerated IDs examples ### #
@@ -269,7 +269,7 @@ with models.DAG(
 
 
 with models.DAG(
-    'example_gcp_vision_explicit_id', start_date=days_ago(1), schedule_interval=None
+    'example_gcp_vision_explicit_id', schedule_interval='@once', start_date=days_ago(1)
 ) as dag_explicit_id:
     # ############################# #
     # ### Explicit IDs examples ### #
@@ -434,7 +434,7 @@ with models.DAG(
     remove_product_from_product_set_2 >> product_delete_2
 
 with models.DAG(
-    'example_gcp_vision_annotate_image', start_date=days_ago(1), schedule_interval=None
+    'example_gcp_vision_annotate_image', schedule_interval='@once', start_date=days_ago(1)
 ) as dag_annotate_image:
     # ############################## #
     # ### Annotate image example ### #
