@@ -30,7 +30,7 @@ from typing import Dict, List, Optional, Sequence, Set, Tuple, Union
 
 from google.api_core.exceptions import AlreadyExists, NotFound
 from google.api_core.retry import Retry, exponential_sleep_generator
-from google.cloud.dataproc_v1beta2 import Cluster
+from google.cloud.dataproc_v1 import Cluster
 from google.protobuf.duration_pb2 import Duration
 from google.protobuf.field_mask_pb2 import FieldMask
 
@@ -135,14 +135,14 @@ class ClusterGenerator:
     :type optional_components: list[str]
     :param num_masters: The # of master nodes to spin up
     :type num_masters: int
-    :param master_machine_type: Compute engine machine type to use for the master node
+    :param master_machine_type: Compute engine machine type to use for the primary node
     :type master_machine_type: str
-    :param master_disk_type: Type of the boot disk for the master node
+    :param master_disk_type: Type of the boot disk for the primary node
         (default is ``pd-standard``).
         Valid values: ``pd-ssd`` (Persistent Disk Solid State Drive) or
         ``pd-standard`` (Persistent Disk Hard Disk Drive).
     :type master_disk_type: str
-    :param master_disk_size: Disk size for the master node
+    :param master_disk_size: Disk size for the primary node
     :type master_disk_size: int
     :param worker_machine_type: Compute engine machine type to use for the worker nodes
     :type worker_machine_type: str
@@ -293,9 +293,7 @@ class ClusterGenerator:
 
     def _build_gce_cluster_config(self, cluster_data):
         if self.zone:
-            zone_uri = 'https://www.googleapis.com/compute/v1/projects/{}/zones/{}'.format(
-                self.project_id, self.zone
-            )
+            zone_uri = f'https://www.googleapis.com/compute/v1/projects/{self.project_id}/zones/{self.zone}'
             cluster_data['gce_cluster_config']['zone_uri'] = zone_uri
 
         if self.metadata:
@@ -393,8 +391,8 @@ class ClusterGenerator:
         elif self.custom_image:
             project_id = self.custom_image_project_id or self.project_id
             custom_image_url = (
-                'https://www.googleapis.com/compute/beta/projects/'
-                '{}/global/images/{}'.format(project_id, self.custom_image)
+                f'https://www.googleapis.com/compute/beta/projects/{project_id}'
+                f'/global/images/{self.custom_image}'
             )
             cluster_data['master_config']['image_uri'] = custom_image_url
             if not self.single_node:
@@ -550,10 +548,10 @@ class DataprocCreateClusterOperator(BaseOperator):
         # TODO: remove one day
         if cluster_config is None:
             warnings.warn(
-                "Passing cluster parameters by keywords to `{}` "
-                "will be deprecated. Please provide cluster_config object using `cluster_config` parameter. "
-                "You can use `airflow.dataproc.ClusterGenerator.generate_cluster` method to "
-                "obtain cluster object.".format(type(self).__name__),
+                f"Passing cluster parameters by keywords to `{type(self).__name__}` will be deprecated. "
+                "Please provide cluster_config object using `cluster_config` parameter. "
+                "You can use `airflow.dataproc.ClusterGenerator.generate_cluster` "
+                "method to obtain cluster object.",
                 DeprecationWarning,
                 stacklevel=1,
             )
@@ -773,9 +771,8 @@ class DataprocScaleClusterOperator(BaseOperator):
 
         # TODO: Remove one day
         warnings.warn(
-            "The `{cls}` operator is deprecated, please use `DataprocUpdateClusterOperator` instead.".format(
-                cls=type(self).__name__
-            ),
+            f"The `{type(self).__name__}` operator is deprecated, "
+            "please use `DataprocUpdateClusterOperator` instead.",
             DeprecationWarning,
             stacklevel=1,
         )
@@ -1673,7 +1670,7 @@ class DataprocCreateWorkflowTemplateOperator(BaseOperator):
                     "Parameter `location` will be deprecated. "
                     "Please provide value through `region` parameter instead.",
                     DeprecationWarning,
-                    stacklevel=1,
+                    stacklevel=2,
                 )
                 region = location
             else:
@@ -1909,7 +1906,7 @@ class DataprocSubmitJobOperator(BaseOperator):
     :type location: str
     :param job: Required. The job resource.
         If a dict is provided, it must be of the same form as the protobuf message
-        :class:`~google.cloud.dataproc_v1beta2.types.Job`
+        :class:`~google.cloud.dataproc_v1.types.Job`
     :type job: Dict
     :param request_id: Optional. A unique id used to identify the request. If the server receives two
         ``SubmitJobRequest`` requests with the same id, then the second request will be ignored and the first
@@ -1974,7 +1971,7 @@ class DataprocSubmitJobOperator(BaseOperator):
                     "Parameter `location` will be deprecated. "
                     "Please provide value through `region` parameter instead.",
                     DeprecationWarning,
-                    stacklevel=1,
+                    stacklevel=2,
                 )
                 region = location
             else:
@@ -2050,8 +2047,8 @@ class DataprocUpdateClusterOperator(BaseOperator):
     :param cluster: Required. The changes to the cluster.
 
         If a dict is provided, it must be of the same form as the protobuf message
-        :class:`~google.cloud.dataproc_v1beta2.types.Cluster`
-    :type cluster: Union[Dict, google.cloud.dataproc_v1beta2.types.Cluster]
+        :class:`~google.cloud.dataproc_v1.types.Cluster`
+    :type cluster: Union[Dict, google.cloud.dataproc_v1.types.Cluster]
     :param update_mask: Required. Specifies the path, relative to ``Cluster``, of the field to update. For
         example, to change the number of workers in a cluster to 5, the ``update_mask`` parameter would be
         specified as ``config.worker_config.num_instances``, and the ``PATCH`` request body would specify the
@@ -2116,7 +2113,7 @@ class DataprocUpdateClusterOperator(BaseOperator):
                     "Parameter `location` will be deprecated. "
                     "Please provide value through `region` parameter instead.",
                     DeprecationWarning,
-                    stacklevel=1,
+                    stacklevel=2,
                 )
                 region = location
             else:
