@@ -20,7 +20,7 @@
 import warnings
 from typing import Optional
 
-from google.cloud.dataproc_v1beta2.types import JobStatus
+from google.cloud.dataproc_v1.types import JobStatus
 
 from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.dataproc import DataprocHook
@@ -63,7 +63,7 @@ class DataprocJobSensor(BaseSensorOperator):
                     "Parameter `location` will be deprecated. "
                     "Please provide value through `region` parameter instead.",
                     DeprecationWarning,
-                    stacklevel=1,
+                    stacklevel=2,
                 )
                 region = location
             else:
